aboutsummaryrefslogtreecommitdiff
path: root/src/pkg/http/transfer.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/http/transfer.go')
-rw-r--r--src/pkg/http/transfer.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/pkg/http/transfer.go b/src/pkg/http/transfer.go
index 5d32aabbfa..0fa8bed43a 100644
--- a/src/pkg/http/transfer.go
+++ b/src/pkg/http/transfer.go
@@ -442,15 +442,15 @@ type body struct {
closed bool
}
// ErrBodyReadAferClose is returned when reading a Request Body after
// the body has been closed. This typically happens when the body is
// read after an HTTP Handler calls WriteHeader or Write on its
// ResponseWriter.
-var ErrBodyReadAferClose = os.NewError("http: invalid Read on closed request Body")
+var ErrBodyReadAfterClose = os.NewError("http: invalid Read on closed request Body")
func (b *body) Read(p []byte) (n int, err os.Error) {
if b.closed {
- return 0, ErrBodyReadAferClose
+ return 0, ErrBodyReadAfterClose
}
return b.Reader.Read(p)
}
@@ -442,15 +442,15 @@ type body struct {
closed bool
}
-// ErrBodyReadAferClose is returned when reading a Request Body after
+// ErrBodyReadAfterClose is returned when reading a Request Body after
// the body has been closed. This typically happens when the body is
// read after an HTTP Handler calls WriteHeader or Write on its